#!/usr/bin/env python3
#
# About program:
# RMIC - RAID Massive IOPS Counter
# Program for count IOPS and Disks in the RAID groups
__version__ = '1.1'
__author__ = 'Karpukhin Pavel <---my@mail.com--->'
__license__ = 'Public Domain'
#__url__ = 'http://---.ru'
#

# Import needed modules
import os
import math
from os import system
from os import name
#####

# Script colorization (by os.name)
class TxtColors:
    # for Windows
    if name == 'nt':
        ColorEND = ''
        ColorRED = ''
        ColorGREEN = ''
        ColorYELLOW = ''
        ColorBLUEBG = ''
        ColorBLUE = ''
        ColorWHITE = ''
    # for Linux
    else:
        ColorEND = '\33[0m'
        ColorRED = '\33[31m'
        ColorGREEN = '\33[32m'
        ColorYELLOW = '\33[33m'
        ColorBLUEBG = '\33[44m'
        ColorBLUE = '\33[34m'
        ColorWHITE = '\33[37m'


# Clear screen (by os.name)
def clear():
    # for Windows
    if name == 'nt':
        _ = system('cls')
    # for Linux
    else:
        _ = system('clear')


# Print program name
def program_name():
    print(TxtColors.ColorBLUEBG + 'RMIC (RAID Massive IOPS Counter)' + TxtColors.ColorEND + '\n')


# Choise you variant for count
def choise_counter():
    chcnt = ''
    while not(chcnt == '1' or chcnt == '2' or chcnt == '3'):
        chcnt = input('Что вы хотите посчитать?\n [1] Количество дисков под заданные IOPS-ы \n [2] Количество IOPS выдаваемых массивом \n [3] Ничего, хочу закрыть программу \n')

    if chcnt == '1':
        return('1')
    elif chcnt == '2':
        return('2')
    else:
        clear()
        exit()


# Rerun program
def replay():
    return input('Хотите повторить расчёты? [Yes | No]: \n').lower().startswith('y')


# Disk size
def disk_size():
    return input('Укажите размер одного диска в Гб: ')


# Disk prise
def disk_prise():
    return input('Укажите стоимость одного диска в $: ')


# Number of disks in RAID group
def user_disks():
    disks = 0
    disks_massive = list(range(2,1001))
    try:
        while int(disks) not in disks_massive:
            disks = input('Сколько дисков вы планируете использовать? ')
    except ValueError:
        print('Вводите только цифры.\nРабота завершена.')
        exit()
    else:
        return int(disks)


# IOPS by one disk
def disk_iops():
    iops = 0
    iops_massive = list(range(1,1000001))
    try:
        while int(iops) not in iops_massive:
            iops = input('\n============-Примерные значения IOPS-============\n 5.4k RPM -  50   IOPS | 7.2k RPM - 75    IOPS | SSD(SATA) - 90k IOPS\n 10k  RPM -  160  IOPS | 15k  RPM - 200   IOPS |\n SSD(SLC)  - 150k IOPS | SSD(MLC)  - 131k IOPS | SSD(cMLC) - 107k IOPS  \n NVMe - 145k-700k IOPS\n=================================================\nСколько IOPS может выдать один ваш диск? ')
    except ValueError:
        print('Вводите только цифры.\nРабота завершена.')
        exit()
    else:
        return int(iops)


# IOPS by all disks
def disks_iops():
    iops_all = 0
    iops_all_massive = list(range(1,1000001))
    try:
        while int(iops_all) not in iops_all_massive:
            iops_all = input('Сколько IOPS должен выдать весь массив? ')
    except ValueError:
        print('Вводите только цифры.\nРабота завершена.')
        exit()
    else:
        return int(iops_all)


# Read %
def pw_read():
    pr = 0
    pr_massive = list(range(1,101))
    try:
        while int(pr) not in pr_massive:
            pr = input('Какова будет нагрузка по чтению в %? ')
    except ValueError:
        print('Вводите только цифры.\nРабота завершена.')
        exit()
    else:
        return int(pr)


# Disk comparsion
def raid_massive_attributes(money, one_disk_size, count_disks, raid_type, iops_count):
    massive_size = one_disk_size * count_disks
    if money > 0 and one_disk_size > 0:
        iops_ratio_cur = round(((money * count_disks) / iops_count), 2)
        size_ratio_cur = round(((money * count_disks) / massive_size), 2)
    else:
        iops_ratio_cur = 'нехватает данных для расчёта'
        size_ratio_cur = 'нехватает данных для расчёта'
    
    if one_disk_size > 0:
        raw_size = count_disks * one_disk_size
        iops_ratio_gb = round((iops_count / raw_size), 2)
        
        if raw_size > 999:
            raw_size_t = round((raw_size / 1000), 2)
            raw_size = str(raw_size_t) + ' Тб'
        else:
            raw_size = str(raw_size) + ' Гб'
        
        if raid_type == 'raid1' or  raid_type == 'raid10':
            wrk_size = massive_size / 2
        elif raid_type == 'raid5':
            wrk_size = massive_size - one_disk_size
        else:
            wrk_size = massive_size - (one_disk_size * 2)
        
        if wrk_size > 999:
            wrk_size_t = round((wrk_size / 1000), 2)
            wrk_size = str(wrk_size_t) + ' Тб'
        else:
            wrk_size = str(int(wrk_size)) + ' Гб'
        
    else:
        raw_size = 'нехватает данных для расчёта'
        wrk_size = 'нехватает данных для расчёта'
        iops_ratio_gb = 'нехватает данных для расчёта'
    
    return[raw_size,wrk_size,iops_ratio_gb,iops_ratio_cur,size_ratio_cur]


while True:
    # Clear screen and start program
    clear()
    program_name()
    game_on = True

    while game_on:
        if choise_counter() == '1':
            clear()
            program_name()
            print('Считаем количество дисков под заданные IOPS-ы \n')
            print('==========Задаём параметры для расчёта:==========\n')
            
            pr_io_all = int(disks_iops())
            pr_io = disk_iops()
            pr_rd = pw_read()
            
            pr_sz_tmp = disk_size()
            if not pr_sz_tmp.isdigit():
                pr_sz = 0
            else:
                pr_sz = int(pr_sz_tmp)
            
            if pr_sz > 999:
                pr_sz_show_t = round((pr_sz / 1000), 2)
                pr_sz_show = str(pr_sz_show_t) + ' Тб'
            else:
                pr_sz_show = str(pr_sz) + ' Гб'
            
            money_tmp = disk_prise()
            if not money_tmp.isdigit():
                money = 0
            else:
                money = int(money_tmp)
            
            pr_rw = 100 - pr_rd
            wrk_rd = pr_rd / 100
            wrk_rw_back = pr_rw / 100
            
            # RAID-1 penalty = 2
            wrk_rw = (pr_rw / 100) / 2
            raid_1_disks_tmp = math.ceil(round(((pr_io_all / (wrk_rd + wrk_rw)) / pr_io), 2))
            if (raid_1_disks_tmp / 2) == 1:
                raid_1_disks = raid_1_disks_tmp
                raid_1_iops = round(((pr_io_all * wrk_rw_back) / 2) + (pr_io_all * wrk_rd))
                raid1_attr = raid_massive_attributes(money, pr_sz, raid_1_disks, 'raid1', raid_1_iops)
            else:
                raid_1_disks = 'не применимо'
            
            # RAID-10 penalty = 2
            raid_10_disks_tmp = math.ceil(round(((pr_io_all / (wrk_rd + wrk_rw)) / pr_io), 2))
            if (raid_10_disks_tmp % 2) == 0 and raid_10_disks_tmp > 3:
                raid_10_disks = raid_10_disks_tmp
                raid_10_iops = round(((pr_io_all * wrk_rw_back) / 2) + (pr_io_all * wrk_rd))
                raid10_attr = raid_massive_attributes(money, pr_sz, raid_10_disks, 'raid10', raid_10_iops)
            else:
                if raid_10_disks_tmp == 1:
                    all_iops10_up = 4 * pr_io
                    raid_10_disks = 'не применимо'
                    raid_10_iops = round(((all_iops10_up * wrk_rw_back) / 2) + (all_iops10_up * wrk_rd))
                    raid_10_iops_up_text = ', нужно не менее 4-х дисков, которые дадут - ' + str(raid_10_iops) + ' iops'
                    raid10_attr = raid_massive_attributes(money, pr_sz, 4, 'raid10', raid_10_iops)
                else:
                    raid_10_disks = 'не применимо'
                    if (raid_10_disks_tmp % 2) == 0:
                        if raid_10_disks_tmp == 2:
                            raid_10_disks_many = raid_10_disks_tmp + 2
                        else:
                            raid_10_disks_many = raid_10_disks_tmp
                    else:
                        raid_10_disks_many = raid_10_disks_tmp + 1
                    
                    all_iops10_up = raid_10_disks_many * pr_io
                    raid_10_iops = round(((all_iops10_up * wrk_rw_back) / 2) + (all_iops10_up * wrk_rd))
                    raid_10_iops_up_text = ', нужно не менее ' + str(raid_10_disks_many) + ' дисков, которые дадут - ' + str(raid_10_iops) + ' iops'
                    raid10_attr = raid_massive_attributes(money, pr_sz, raid_10_disks_many, 'raid10', raid_10_iops)
            
            # RAID-5 penalty = 4
            wrk_rw5 = (pr_rw / 100) / 4
            raid_5_disks_tmp = math.ceil(round(((pr_io_all / (wrk_rd + wrk_rw5)) / pr_io), 2))
            if raid_5_disks_tmp < 3:
                all_iops5_up = 3 * pr_io
                raid_5_iops_up = round(((all_iops5_up * wrk_rw_back) / 4) + (all_iops5_up * wrk_rd))
                raid_5_iops_up_text = ', нужно не менее 3-х дисков, которые дадут - ' + str(raid_5_iops_up) + ' iops'
                raid_5_disks = 'не применимо'
                raid5_attr = raid_massive_attributes(money, pr_sz, 3, 'raid5', raid_5_iops_up)
            else:
                raid_5_disks = raid_5_disks_tmp
                raid_5_iops = round(((pr_io_all * wrk_rw_back) / 4) + (pr_io_all * wrk_rd))
                raid5_attr = raid_massive_attributes(money, pr_sz, raid_5_disks, 'raid5', raid_5_iops)
            
            # RAID-6 penalty = 6
            wrk_rw6 = (pr_rw / 100) / 6
            raid_6_disks_tmp = math.ceil(round(((pr_io_all / (wrk_rd + wrk_rw6)) / pr_io), 2))
            if raid_6_disks_tmp < 4:
                all_iops6_up = 4 * pr_io
                raid_6_iops_up = round(((all_iops6_up * wrk_rw_back) / 6) + (all_iops6_up * wrk_rd))
                raid_6_iops_up_text = ', нужно не менее 4-х дисков, которые дадут - ' + str(raid_6_iops_up) + ' iops'
                raid_6_disks = 'не применимо'
                raid6_attr = raid_massive_attributes(money, pr_sz, 4, 'raid6', raid_6_iops_up)
            else:
                raid_6_disks = raid_6_disks_tmp
                raid_6_iops = round(((pr_io_all * wrk_rw_back) / 6) + (pr_io_all * wrk_rd))
                raid6_attr = raid_massive_attributes(money, pr_sz, raid_6_disks, 'raid6', raid_6_iops)
            
            clear()
            program_name()
            print('Считаем количество дисков под заданные IOPS-ы \n')
            print('========Текущие параметры для расчёта:========\n')
            
            if pr_sz == 0:
                print('Весь массив должен выдавать - ' + TxtColors.ColorYELLOW + str(pr_io_all) + ' iops' + TxtColors.ColorEND)
                print('Один диск может выдать      - ' + TxtColors.ColorYELLOW + str(pr_io) + ' iops' + TxtColors.ColorEND)
                print('Процент запросов на чтение  - ' + TxtColors.ColorYELLOW + str(pr_rd) + '%' + TxtColors.ColorEND)
                print('Процент запросов на запись  - ' + TxtColors.ColorYELLOW + str(pr_rw) + '%\n' + TxtColors.ColorEND)
            else:
                print('Весь массив должен выдавать - ' + TxtColors.ColorYELLOW + str(pr_io_all) + ' iops' + TxtColors.ColorEND)
                print('Один диск может выдать      - ' + TxtColors.ColorYELLOW + str(pr_io) + ' iops' + TxtColors.ColorEND)
                print('Ёмкость одного диска равна  - ' + TxtColors.ColorYELLOW + str(pr_sz_show) + TxtColors.ColorEND)
                print('Процент запросов на чтение  - ' + TxtColors.ColorYELLOW + str(pr_rd) + '%' + TxtColors.ColorEND)
                print('Процент запросов на запись  - ' + TxtColors.ColorYELLOW + str(pr_rw) + '%\n' + TxtColors.ColorEND)
            
            print('========Результаты расчёта:========\n')
            if raid_1_disks == 'не применимо':
                print('RAID-1 - ' + TxtColors.ColorRED + str(raid_1_disks) + TxtColors.ColorEND)
            else:
                print('RAID-1 потребуется   - ' + TxtColors.ColorGREEN + str(raid_1_disks) + ' диска' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid1_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid1_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid1_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid1_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid1_attr[4]) + '\n' + TxtColors.ColorEND)
            
            if raid_10_disks == 'не применимо':
                print('RAID-10 - ' + TxtColors.ColorRED + str(raid_10_disks) + str(raid_10_iops_up_text) + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid10_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid10_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid10_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid10_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid10_attr[4]) + '\n' + TxtColors.ColorEND)
            else:
                print('RAID-10 потребуется  - ' + TxtColors.ColorGREEN + str(raid_10_disks) + ' дисков' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid10_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid10_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid10_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid10_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid10_attr[4]) + '\n' + TxtColors.ColorEND)
            
            if raid_5_disks == 'не применимо':
                print('RAID-5 - ' + TxtColors.ColorRED + str(raid_5_disks) + str(raid_5_iops_up_text) + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid5_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid5_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid5_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid5_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid5_attr[4]) + '\n' + TxtColors.ColorEND)
            else:
                print('RAID-5 потребуется   - ' + TxtColors.ColorGREEN + str(raid_5_disks) + ' дисков' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid5_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid5_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid5_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid5_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid5_attr[4]) + '\n' + TxtColors.ColorEND)
            
            if raid_6_disks == 'не применимо':
                print('RAID-6 - ' + TxtColors.ColorRED + str(raid_6_disks) + str(raid_6_iops_up_text) + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid6_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid6_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid6_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid6_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid6_attr[4]) + '\n' + TxtColors.ColorEND)
            else:
                print('RAID-6 потребуется   - ' + TxtColors.ColorGREEN + str(raid_6_disks) + ' дисков' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid6_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid6_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid6_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid6_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid6_attr[4]) + '\n' + TxtColors.ColorEND)
            
            print('===================================\n')
            game_on = False
        
        else:
            clear()
            program_name()
            print('Считаем количество IOPS выдаваемых массивом \n')
            print('==========Задаём параметры для расчёта:==========\n')
            
            pr_rd = pw_read()
            pr_ud = user_disks()
            pr_rw = 100 - pr_rd
            pr_io = disk_iops()
            
            pr_sz_tmp = disk_size()
            if not pr_sz_tmp.isdigit():
                pr_sz = 0
            else:
                pr_sz = int(pr_sz_tmp)
            
            if pr_sz > 999:
                pr_sz_show_t = round((pr_sz / 1000), 2)
                pr_sz_show = str(pr_sz_show_t) + ' Тб'
            else:
                pr_sz_show = str(pr_sz) + ' Гб'
            
            money_tmp = disk_prise()
            if not money_tmp.isdigit():
                money = 0
            else:
                money = int(money_tmp)
            
            all_iops = pr_ud * pr_io
            wrk_rd = pr_rd / 100
            wrk_rw = pr_rw / 100
            
            # RAID-1 penalty = 2
            if (pr_ud / 2) == 1:
                raid_1_iops = round(((all_iops * wrk_rw) / 2) + (all_iops * wrk_rd))
                raid1_attr = raid_massive_attributes(money, pr_sz, pr_ud, 'raid1', raid_1_iops)
            else:
                raid_1_iops = 'не применимо'
            
            # RAID-10 penalty = 2
            if pr_ud < 3:
                all_iops10_up = 4 * pr_io
                raid_10_iops_up = round(((all_iops10_up * wrk_rw) / 2) + (all_iops10_up * wrk_rd))
                raid_10_iops = 'не применимо'
                raid_10_iops_up_text = ', нужно не менее 4-х дисков, которые дадут - ' + str(raid_10_iops_up) + ' iops'
                raid10_attr = raid_massive_attributes(money, pr_sz, 4, 'raid10', raid_10_iops_up)
            elif (pr_ud % 2) == 0:
                raid_10_iops = round(((all_iops * wrk_rw) / 2) + (all_iops * wrk_rd))
                raid10_attr = raid_massive_attributes(money, pr_sz, pr_ud, 'raid10', raid_10_iops)
            else:
                if (pr_ud % 2) == 0:
                    if pr_ud == 2:
                        pr_ud_new = pr_ud + 2
                    else:
                        pr_ud_new = pr_ud
                else:
                    pr_ud_new = pr_ud + 1
                
                all_iops10_up = pr_ud_new * pr_io
                raid_10_iops_up = round(((all_iops10_up * wrk_rw) / 2) + (all_iops10_up * wrk_rd))
                raid_10_iops = 'не применимо'
                raid_10_iops_up_text = ', ' + str(pr_ud_new) +' диска(ов) дадут - ' + str(raid_10_iops_up) + ' iops'
                raid10_attr = raid_massive_attributes(money, pr_sz, pr_ud_new, 'raid10', raid_10_iops_up)
            
            # RAID-5 penalty = 4
            if pr_ud > 2:
                raid_5_iops = round(((all_iops * wrk_rw) / 4) + (all_iops * wrk_rd))
                raid5_attr = raid_massive_attributes(money, pr_sz, pr_ud, 'raid5', raid_5_iops)
            else:
                all_iops5_up = 3 * pr_io
                raid_5_iops_up = round(((all_iops5_up * wrk_rw) / 4) + (all_iops5_up * wrk_rd))
                raid_5_iops = 'не применимо'
                raid_5_iops_up_text = ', нужно не менее 3-х дисков, которые дадут - ' + str(raid_5_iops_up) + ' iops'
                raid5_attr = raid_massive_attributes(money, pr_sz, 3, 'raid5', raid_5_iops_up)
            
            # RAID-6 penalty = 6
            if pr_ud > 3:
                raid_6_iops = round(((all_iops * wrk_rw) / 6) + (all_iops * wrk_rd))
                raid6_attr = raid_massive_attributes(money, pr_sz, pr_ud, 'raid6', raid_6_iops)
            else:
                all_iops6_up = 4 * pr_io
                raid_6_iops_up = round(((all_iops6_up * wrk_rw) / 6) + (all_iops6_up * wrk_rd))
                raid_6_iops = 'не применимо'
                raid_6_iops_up_text = ', нужно не менее 4-х дисков, которые дадут - ' + str(raid_6_iops_up) + ' iops'
                raid6_attr = raid_massive_attributes(money, pr_sz, 4, 'raid6', raid_6_iops_up)
            
            clear()
            program_name()
            print('Считаем количество IOPS выдаваемых массивом \n')
            print('========Текущие параметры для расчёта:========\n')
            print('Считаем массив для         - ' + TxtColors.ColorYELLOW + str(pr_ud) + ' дисков' + TxtColors.ColorEND)
            print('Один диск может выдать     - ' + TxtColors.ColorYELLOW + str(pr_io) + ' iops' + TxtColors.ColorEND)
            print('Процент запросов на чтение - ' + TxtColors.ColorYELLOW + str(pr_rd) + '%' + TxtColors.ColorEND)
            print('Процент запросов на запись - ' + TxtColors.ColorYELLOW + str(pr_rw) + '%\n' + TxtColors.ColorEND)
            
            print('========Результаты расчёта:========\n')
            if raid_1_iops == 'не применимо':
                print('RAID-1 - ' + TxtColors.ColorRED + str(raid_1_iops) + TxtColors.ColorEND)
            else:
                print('RAID-1 выдаст примерно  - ' + TxtColors.ColorGREEN + str(raid_1_iops) + ' iops' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid1_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid1_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid1_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid1_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid1_attr[4]) + '\n' + TxtColors.ColorEND)
            
            if raid_10_iops == 'не применимо':
                print('RAID-10 - ' + TxtColors.ColorRED + str(raid_10_iops) + str(raid_10_iops_up_text) + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid10_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid10_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid10_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid10_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid10_attr[4]) + '\n' + TxtColors.ColorEND)
            else:
                print('RAID-10 выдаст примерно - ' + TxtColors.ColorGREEN + str(raid_10_iops) + ' iops' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid10_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid10_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid10_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid10_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid10_attr[4]) + '\n' + TxtColors.ColorEND)
            
            if raid_5_iops == 'не применимо':
                print('RAID-5 - ' + TxtColors.ColorRED + str(raid_5_iops) + str(raid_5_iops_up_text) + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid5_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid5_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid5_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid5_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid5_attr[4]) + '\n' + TxtColors.ColorEND)
            else:
                print('RAID-5 выдаст примерно - ' + TxtColors.ColorGREEN + str(raid_5_iops) + ' iops' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid5_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid5_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid5_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid5_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid5_attr[4]) + '\n' + TxtColors.ColorEND)
            
            if raid_6_iops == 'не применимо':
                print('RAID-6 - ' + TxtColors.ColorRED + str(raid_6_iops) + str(raid_6_iops_up_text) + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid6_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid6_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid6_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid6_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid6_attr[4]) + '\n' + TxtColors.ColorEND)
            else:
                print('RAID-6 выдаст примерно - ' + TxtColors.ColorGREEN + str(raid_6_iops) + ' iops' + TxtColors.ColorEND)
                print('  Сырая ёмкость      - ' + TxtColors.ColorWHITE + str(raid6_attr[0]) + TxtColors.ColorEND)
                print('  Рабочая ёмкость    - ' + TxtColors.ColorWHITE + str(raid6_attr[1]) + TxtColors.ColorEND)
                print('  Отношение IOPS/Gb  - ' + TxtColors.ColorWHITE + str(raid6_attr[2]) + TxtColors.ColorEND)
                print('  Отношение $/Gb     - ' + TxtColors.ColorWHITE + str(raid6_attr[3]) + TxtColors.ColorEND)
                print('  Отношение $/IOPS   - ' + TxtColors.ColorWHITE + str(raid6_attr[4]) + '\n' + TxtColors.ColorEND)
            
            print('===================================\n')
            game_on = False

    if not replay():
        print('\n Пока!\n')
        break
